@@ -1,13 +1,13 @@
 package App::shcompgen;
 
-our $DATE = '2015-02-11'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::Slurp::Tiny qw(read_file write_file);
 use Perinci::Object;
@@ -617,7 +617,7 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.09 of App::shcompgen (from Perl distribution App-shcompgen), released on 2015-02-11.
+This document describes version 0.10 of App::shcompgen (from Perl distribution App-shcompgen), released on 2015-08-17.
 
 =head1 FUNCTIONS
 
@@ -630,7 +630,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
+=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions","/etc/bash_completion.d"])
 
 {en_US Directory to put completions scripts}.
 
@@ -705,7 +705,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
+=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions","/etc/bash_completion.d"])
 
 {en_US Directory to put completions scripts}.
 
@@ -758,7 +758,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
+=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions","/etc/bash_completion.d"])
 
 {en_US Directory to put completions scripts}.
 
@@ -813,7 +813,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
+=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions","/etc/bash_completion.d"])
 
 {en_US Directory to put completions scripts}.
 
